@@ -1,18 +1,12 @@
-import re
-import string
 import zipfile
 from abc import ABCMeta, abstractmethod
-from enum import Enum
 from itertools import chain
 from pathlib import Path
 from typing import Union, Optional
 
+from mloader.constants import Language
 from mloader.response_pb2 import Title, Chapter
-
-
-class Language(Enum):
-    eng = 0
-    spa = 1
+from mloader.utils import escape_path, is_oneshot, chapter_name_to_int
 
 
 class ExporterBase(metaclass=ABCMeta):
@@ -22,10 +16,12 @@ class ExporterBase(metaclass=ABCMeta):
         title: Title,
         chapter: Chapter,
         next_chapter: Optional[Chapter] = None,
+        add_chapter_title: bool = False,
     ):
         self.destination = destination
-        self.title_name = self.escape_path(title.name).title()
-        self.is_oneshot = self._is_oneshot(chapter.name, chapter.sub_title)
+        self.add_chapter_title = add_chapter_title
+        self.title_name = escape_path(title.name).title()
+        self.is_oneshot = is_oneshot(chapter.name, chapter.sub_title)
         self.is_extra = chapter.name == "ex"
 
         self._extra_info = []
@@ -33,8 +29,8 @@ class ExporterBase(metaclass=ABCMeta):
         if self.is_oneshot:
             self._extra_info.append("[Oneshot]")
 
-        if self.is_extra:
-            self._extra_info.append(f"[{self.escape_path(chapter.sub_title)}]")
+        if self.is_extra or self.add_chapter_title:
+            self._extra_info.append(f"[{escape_path(chapter.sub_title)}]")
 
         self._chapter_prefix = self._format_chapter_prefix(
             self.title_name,
@@ -47,19 +43,6 @@ class ExporterBase(metaclass=ABCMeta):
             (self._chapter_prefix, self._chapter_suffix)
         )
 
-    def _is_oneshot(self, chapter_name: str, chapter_subtitle: str) -> bool:
-        for name in (chapter_name, chapter_subtitle):
-            name = name.lower()
-            if "one" in name and "shot" in name:
-                return True
-        return False
-
-    def _chapter_name_to_int(self, name: str) -> Optional[int]:
-        try:
-            return int(name.lstrip("#"))
-        except ValueError:
-            return None
-
     def _format_chapter_prefix(
         self,
         title_name: str,
@@ -78,17 +61,17 @@ class ExporterBase(metaclass=ABCMeta):
             chapter_num = 0
         elif self.is_extra and next_chapter_name:
             suffix = "x1"
-            chapter_num = self._chapter_name_to_int(next_chapter_name)
+            chapter_num = chapter_name_to_int(next_chapter_name)
             if chapter_num is not None:
                 chapter_num -= 1
                 prefix = "c" if chapter_num < 1000 else "d"
         else:
-            chapter_num = self._chapter_name_to_int(chapter_name)
+            chapter_num = chapter_name_to_int(chapter_name)
             if chapter_num is not None:
                 prefix = "c" if chapter_num < 1000 else "d"
 
         if chapter_num is None:
-            chapter_num = self.escape_path(chapter_name)
+            chapter_num = escape_path(chapter_name)
 
         components.append(f"{prefix}{chapter_num:0>3}{suffix}")
         components.append("(web)")
@@ -103,13 +86,10 @@ class ExporterBase(metaclass=ABCMeta):
         else:
             page = f"p{page:0>3}"
 
-        ext = ext.lstrip('.')
+        ext = ext.lstrip(".")
 
         return f"{self._chapter_prefix} - {page} {self._chapter_suffix}.{ext}"
 
-    def escape_path(self, path: str) -> str:
-        return re.sub(r"[^\w]+", " ", path).strip(string.punctuation + " ")
-
     def close(self):
         pass
 
@@ -119,14 +99,8 @@ class ExporterBase(metaclass=ABCMeta):
 
 
 class RawExporter(ExporterBase):
-    def __init__(
-        self,
-        destination: str,
-        title: Title,
-        chapter: Chapter,
-        next_chapter: Optional[Chapter] = None,
-    ):
-        super().__init__(destination, title, chapter, next_chapter)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.path = Path(self.destination, self.title_name)
         self.path.mkdir(parents=True, exist_ok=True)
 
@@ -136,15 +110,8 @@ class RawExporter(ExporterBase):
 
 
 class CBZExporter(ExporterBase):
-    def __init__(
-        self,
-        destination: str,
-        title: Title,
-        chapter: Chapter,
-        next_chapter: Optional[Chapter] = None,
-        compression=zipfile.ZIP_DEFLATED,
-    ):
-        super().__init__(destination, title, chapter, next_chapter)
+    def __init__(self, compression=zipfile.ZIP_DEFLATED, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self.path = Path(self.destination, self.title_name)
         self.path.mkdir(parents=True, exist_ok=True)
         self.path = self.path.joinpath(self.chapter_name).with_suffix(".cbz")
